ASBS
The ASBS (Arbitrarily Significant Bits) library provides the traits and implementations useful for steganographic concealment and extraction of messages.
Binary implementation
The binary module can be used to encode messages in binary data with bit patterns,
which act as keys and should be shared with the receiver of the message. See its
documentation for details.